@@ -9,9 +9,12 @@ from rpi_featureSelection_python_tools.jmi_tools import *
 # at once in the future, if needed. Otherwise, one could simply inline all these.
 Inputs = ndarray
 Outputs = ndarray
+Params = NamedTuple('Params', [
+    ('estimators', List[]),
+])
 
 
-class JMIFeatureSelector(SupervisedLearnerPrimitiveBase[Inputs, Outputs]):
+class JMIFeatureSelector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params]):
 
     __author__ = "RPI DARPA D3M"
 
