@@ -12,8 +12,11 @@ from rpi_featureSelection_python_tools.stmbplus_tools import *
 # at once in the future, if needed. Otherwise, one could simply inline all these.
 Inputs = ndarray
 Outputs = ndarray
+Params = NamedTuple('Params', [
+    ('estimators', List[]),
+])
 
-class STMBPlusFeatureSelector(SupervisedLearnerPrimitiveBase[Inputs, Outputs]):
+class STMBPlusFeatureSelector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params]):
 
     __author__ = "RPI DARPA D3M"
 
